@@ -20,6 +20,14 @@
 # define MOD_TD "%ld"
 #endif
 
+#if ! HAVE_STRDUP && ! defined strdup
+# if HAVE__STRDUP
+#  define strdup _strdup
+# else
+#  define strdup(str) strcpy(malloc(strlen(str) + 1), str)
+# endif
+#endif
+
 #endif /* pmiscdef.h */
 
 /*
